Package: Synth
Version: 1.1-10
Date: 2026-04-28
Title: Synthetic Control Group Method for Comparative Case Studies
Authors@R: c(person(given = 'Jens', family = 'Hainmueller', role = c('aut','cre'), email = 'jhain@stanford.edu'), person(given = 'Alexis', family = 'Diamond', role = 'aut'))
Description: Implements the synthetic control group method for comparative case studies
 as described in Abadie and Gardeazabal (2003) and Abadie, Diamond, and Hainmueller
 (2010, 2011, 2014). The synthetic control method allows for effect estimation in
 settings where a single unit (a state, country, firm, etc.) is exposed to an event
 or intervention. It provides a data-driven procedure to construct synthetic control
 units based on a weighted combination of comparison units that approximates the
 characteristics of the unit that is exposed to the intervention. A combination of
 comparison units often provides a better comparison for the unit exposed to the
 intervention than any comparison unit alone.
Imports: kernlab, optimx, rgenoud
Suggests: testthat (>= 3.0.0)
Config/testthat/edition: 3
License: GPL (>= 2)
URL: https://web.stanford.edu/~jhain/
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2026-04-28 20:11:25 UTC; jhainmueller
Author: Jens Hainmueller [aut, cre],
  Alexis Diamond [aut]
Maintainer: Jens Hainmueller <jhain@stanford.edu>
Repository: CRAN
Date/Publication: 2026-04-29 06:40:25 UTC
Built: R 4.5.2; ; 2026-04-29 10:44:42 UTC; unix
