.onAttach <-
function (libname, pkgname)
{
   # echo output to screen
   packageStartupMessage("##\n## Synth Package: Implements Synthetic Control Methods.\n")
   packageStartupMessage("## See https://web.stanford.edu/~jhain/synthpage.html for additional information.\n\n")
}


