\name{synth.data}
 \docType{data}
 \alias{synth.data}
 \title{Panel Data to demonstrate the use of the Synthetic Control Method}
 \description{This artificial panel data set is used to demonstrate the use of the 
  Synthetic Control Method. 
          }
\usage{data(synth.data)}
\format{A dataframe made up of 8 units: 1 treated (no 7) and 7 control (no. 2,7,13,17,29,32,36,38)
 , 3 predictors (X1, X2, X3),  21 time periods (1980 - 2000), a unit.names.variable column ("names") and an outcome variable column (Y). All columns have column names.}
\keyword{datasets}

